VFX Naming Conventions Framework
===================================

.. image:: https://github.com/xiancg/vfxnaming/actions/workflows/ci_vfxnaming.yml/badge.svg?event=push&branch=master
.. image:: https://readthedocs.org/projects/naming-conventions/badge/?version=latest
.. image:: https://coveralls.io/repos/github/xiancg/vfxnaming/badge.svg
.. image:: https://img.shields.io/github/license/readthedocs/actions

A complete suite of tools to manage naming conventions from one or more "Rule repositories". Structure naming rules with your own custom tokens. Then use the library to solve names following those rules so your naming is consistent, and also to parse metadata from exisiting names (cus a name is basically a collection of metadata, right?)

Installation
--------------
.. code-block:: python

    pip install vfxnaming

Documentation
---------------
`VFX Naming Conventions Docs <http://naming-conventions.rtfd.io/>`

Acknowledgements
------------------
**vfxnaming** is based on `Copyright (c) 2017 Cesar Saez <https://www.cesarsaez.me/>`_
work. I highly recommend his `Website-Blog <https://www.cesarsaez.me/>`_ and
the video tutorial series on his `YouTube Channel <https://www.youtube.com/channel/UCRjk6bi_1ZQ9sL69agz0xMg>`_ 
